@@ -449,12 +449,15 @@ class ConfigManager:
             'face_emotion': None,
             'flower_segmentation': None,
             'smoker_detection': None,
+            'road_traffic_density': None,
+            'road_view_segmentation': None,
 
             #Put all image based usecases here::
             'blood_cancer_detection_img': None,
             'skin_cancer_classification_img': None,
             'plaque_segmentation_img': None,
             'cardiomegaly_classification': None,
+            'histopathological_cancer_detection' : None,
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -804,6 +807,22 @@ class ConfigManager:
         except ImportError:
             return None
     
+    def road_traffic_density_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.road_traffic_density import RoadTrafficConfig
+            return RoadTrafficConfig
+        except ImportError:
+            return None
+    
+    def road_view_segmentation_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.road_view_segmentation import RoadViewSegmentationConfig
+            return RoadViewSegmentationConfig
+        except ImportError:
+            return None
+    
     #put all image based usecases here::
     def blood_cancer_detection_config_class(self):
         """Register a configuration class for a use case."""
@@ -835,6 +854,14 @@ class ConfigManager:
             return CardiomegalyConfig
         except ImportError:
             return None
+        
+    def histopathological_cancer_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.Histopathological_Cancer_Detection_img import HistopathologicalCancerDetectionConfig
+            return HistopathologicalCancerDetectionConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -1652,6 +1679,38 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "road_traffic_density":
+            # Import here to avoid circular import
+            from ..usecases.road_traffic_density import RoadTrafficConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = RoadTrafficConfig(
+                category=category or "automobile",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        
+        elif usecase == "road_view_segmentation":
+            # Import here to avoid circular import
+            from ..usecases.road_view_segmentation import RoadViewSegmentationConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = RoadViewSegmentationConfig(
+                category=category or "automobile",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
 
         
         #Add IMAGE based usecases here::
@@ -1715,6 +1774,21 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        elif usecase == "histopathological_cancer_detection":
+            # Import here to avoid circular import
+            from ..usecases.Histopathological_Cancer_Detection_img import HistopathologicalCancerDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = HistopathologicalCancerDetectionConfig(
+                category=category or "healthcare",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -2057,6 +2131,16 @@ class ConfigManager:
             from ..usecases.smoker_detection import SmokerDetectionConfig
             default_config = SmokerDetectionConfig()
             return default_config.to_dict()
+        elif usecase == "road_traffic_density":
+            # Import here to avoid circular import
+            from ..usecases.road_traffic_density import RoadTrafficConfig
+            default_config = RoadTrafficConfig()
+            return default_config.to_dict()
+        elif usecase == "road_view_segmentation":
+            # Import here to avoid circular import
+            from ..usecases.road_view_segmentation import RoadViewSegmentationConfig
+            default_config = RoadViewSegmentationConfig()
+            return default_config.to_dict()
 
         #Add all image based usecases here
         elif usecase == "blood_cancer_detection_img":
@@ -2079,6 +2163,11 @@ class ConfigManager:
             from ..usecases.cardiomegaly_classification import CardiomegalyConfig
             default_config = CardiomegalyConfig()
             return default_config.to_dict()
+        elif usecase == "histopathological_cancer_detection":
+            # Import here to avoid circular import
+            from ..usecases.Histopathological_Cancer_Detection_img import HistopathologicalCancerDetectionConfig
+            default_config = HistopathologicalCancerDetectionConfig()
+            return default_config.to_dict()
 
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
