@@ -62,12 +62,15 @@ from .flower_segmentation import FlowerUseCase, FlowerConfig
 from .parking import ParkingConfig, ParkingUseCase
 from .leaf import LeafConfig, LeafUseCase
 from .smoker_detection import SmokerDetectionConfig, SmokerDetectionUseCase
+from .road_traffic_density import RoadTrafficConfig, RoadTrafficUseCase
+from .road_lane_segmentation import RoadViewSegmentationConfig, RoadViewSegmentationUseCase
 
 #Put all IMAGE based usecases here
 from .blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
 from .skin_cancer_classification_img import SkinCancerClassificationConfig, SkinCancerClassificationUseCase
 from .plaque_segmentation_img import PlaqueSegmentationConfig, PlaqueSegmentationUseCase
 from .cardiomegaly_classification import CardiomegalyConfig, CardiomegalyUseCase
+from .Histopathological_Cancer_Detection_img import HistopathologicalCancerDetectionConfig,HistopathologicalCancerDetectionUseCase
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -120,12 +123,15 @@ __all__ = [
     'WindmillMaintenanceUseCase',
     'FlowerUseCase',
     'SmokerDetectionUseCase',
+    'RoadTrafficUseCase',
+    'RoadViewSegmentationUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
     'SkinCancerClassificationUseCase',
     'PlaqueSegmentationUseCase',
     'CardiomegalyUseCase',
+    'HistopathologicalCancerDetectionUseCase',
 
 
 
@@ -178,7 +184,8 @@ __all__ = [
     'WindmillMaintenanceConfig',
     'FlowerConfig',
     'SmokerDetectionConfig',
-
+    'RoadTrafficConfig',
+    'RoadViewSegmentationConfig',
 
 
 
@@ -187,6 +194,7 @@ __all__ = [
     'SkinCancerClassificationConfig',
     'PlaqueSegmentationConfig',
     'CardiomegalyConfig',
+    'HistopathologicalCancerDetectionConfig',
 
 
 ]
\ No newline at end of file
